@@ -27,7 +27,7 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Henryhaoson"
     author_url = "https://git.17bdc.com/android-apps/sentry-dingtalk"
-    version = "8.0.0"
+    version = "9.0.0"
     resource_links = [
         ("Report Issue", "https://git.17bdc.com/android-apps/sentry-dingtalk/issues"),
         ("View Source", "https://git.17bdc.com/android-apps/sentry-dingtalk"),
@@ -109,8 +109,8 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
             ats_ding_str = f"{ats_ding_str} @{at} "
 
         issue_link = group.get_absolute_url(params={"referrer": "dingtalk"})
-        release_link = issue_link.split(
-            "/issues/")[0] + "/releases/" + release+"?project="+project.id
+        release_link_path = issue_link.split("/issues/")[0]
+        release_link = f"{release_link_path}/releases/{release}?project={project.id}"
 
         payload = f"## Error: [{group.title}>>]({issue_link}) \n\n"
         payload = f"{payload} #### UserId: [{userId}](https://admin.shanbay.com/jetty/users/{userId}) \n\n"
